@@ -17,14 +17,12 @@ Extensions currently include external methods.
 import os
 from functools import total_ordering
 
-from six import exec_
-
 import Products
 from zExceptions import NotFound
 
 
 @total_ordering
-class FuncCode(object):
+class FuncCode:
 
     def __init__(self, f, im=0):
         self.co_varnames = f.__code__.co_varnames[im:]
@@ -57,7 +55,7 @@ def _getPath(home, prefix, name, suffixes):
 
     for suffix in suffixes:
         if suffix:
-            fqn = "%s.%s" % (fn, suffix)
+            fqn = f"{fn}.{suffix}"
         else:
             fqn = fn
         if os.path.exists(fqn):
@@ -140,7 +138,7 @@ def getPath(prefix, name, checkProduct=1, suffixes=('',), cfg=None):
 
             for suffix in suffixes:
                 if suffix:
-                    fn = "%s.%s" % (prefix, suffix)
+                    fn = f"{prefix}.{suffix}"
                 else:
                     fn = prefix
                 if os.path.exists(fn):
@@ -182,9 +180,8 @@ def getObject(module, name, reload=0):
     except Exception:
         raise NotFound("The specified module, '%s', "
                        "couldn't be opened." % module)
-    execcode = compile(execsrc, path, 'exec')
     module_dict = {}
-    exec_(execcode, module_dict)
+    exec(execsrc, module_dict)
 
     if old is not None:
         # XXX Accretive??
