@@ -14,11 +14,8 @@
 """
 
 import os
-import sys
 from logging import getLogger
-from warnings import warn
 
-# Waaaa
 import Products
 from AccessControl.Permission import registerPermissions
 from AccessControl.PermissionRole import PermissionRole
@@ -33,14 +30,12 @@ if not hasattr(Products, 'meta_classes'):
     Products.meta_classes = {}
     Products.meta_class_info = {}
 
-if sys.version_info >= (3, ):
-    basestring = str
 
 _marker = []  # Create a new marker object
 LOG = getLogger('ProductContext')
 
 
-class ProductContext(object):
+class ProductContext:
 
     def __init__(self, product, app, package):
         self.__prod = product
@@ -70,7 +65,7 @@ class ProductContext(object):
            meta type will be used.
 
         constructors -- A list of constructor methods
-          A method can me a callable object with a __name__
+          A method can be a callable object with a __name__
           attribute giving the name the method should have in the
           product, or the method may be a tuple consisting of a
           name and a callable object.  The method must be picklable.
@@ -105,7 +100,7 @@ class ProductContext(object):
         pid = productObject.id
 
         if permissions:
-            if isinstance(permissions, basestring):  # You goofed it!
+            if isinstance(permissions, str):  # You goofed it!
                 raise TypeError(
                     'Product context permissions should be a '
                     'list of permissions not a string', permissions)
@@ -177,7 +172,7 @@ class ProductContext(object):
             # 'action': The action in the add drop down in the ZMI. This is
             #           currently also required by the _verifyObjectPaste
             #           method of CopyContainers like Folders.
-            'action': ('manage_addProduct/%s/%s' % (pid, name)),
+            'action': (f'manage_addProduct/{pid}/{name}'),
             # 'product': product id
             'product': pid,
             # 'permission': Guards the add action.
@@ -203,30 +198,11 @@ class ProductContext(object):
                 m[name] = method
                 m[name + '__roles__'] = pr
 
-    def registerHelp(self, directory=None, clear=None, title_re=None):
-        warn('The Help System has been removed from Zope 4. The '
-             'registerHelp method will be removed in Zope 5.',
-             DeprecationWarning, stacklevel=2)
-
-    def registerHelpTitle(self, title=None):
-        warn('The Help System has been removed from Zope 4. The '
-             'registerHelpTitle method will be removed in Zope 5.',
-             DeprecationWarning, stacklevel=2)
-
-    def getProductHelp(self):
-        warn('The Help System has been removed from Zope 4. The '
-             'getProductHelp method will be removed in Zope 5.',
-             DeprecationWarning, stacklevel=2)
-
-        class DummyHelp(object):
-            lastRegistered = None
-        return DummyHelp()
-
     def getApplication(self):
         return self.__app
 
 
-class AttrDict(object):
+class AttrDict:
 
     def __init__(self, ob):
         self.ob = ob
