@@ -51,7 +51,7 @@ def setConfiguration(cfg):
     os.environ["INSTANCE_HOME"] = cfg.instancehome
 
 
-class DefaultConfiguration(object):
+class DefaultConfiguration:
     """
     This configuration should be used effectively only during unit tests
     """
