@@ -13,6 +13,8 @@
 """Role manager
 """
 
+import html
+
 from AccessControl import ClassSecurityInfo
 from AccessControl.class_init import InitializeClass
 from AccessControl.Permission import Permission
@@ -25,12 +27,6 @@ from App.special_dtml import DTMLFile
 from zExceptions import BadRequest
 
 
-try:
-    from html import escape
-except ImportError:  # PY2
-    from cgi import escape
-
-
 class RoleManager(BaseRoleManager):
     """An object that has configurable permissions"""
 
@@ -130,7 +126,7 @@ class RoleManager(BaseRoleManager):
             for role in valid_roles:
                 role_name = role
                 role_hash = _string_hash(role_name)
-                if have("permission_%srole_%s" % (permission_hash, role_hash)):
+                if have(f"permission_{permission_hash}role_{role_hash}"):
                     roles.append(role)
             name, value = permissions[ip][:2]
             try:
@@ -143,7 +139,7 @@ class RoleManager(BaseRoleManager):
 
         if fails:
             raise BadRequest('Some permissions had errors: '
-                             + escape(', '.join(fails), True))
+                             + html.escape(', '.join(fails), True))
         if REQUEST is not None:
             return self.manage_access(REQUEST)
 
