@@ -37,7 +37,7 @@ class ViewPageTemplateFile(TrustedAppPT, PageTemplateFile):
     """
     def __init__(self, filename, _prefix=None, content_type=None):
         _prefix = self.get_path_from_prefix(_prefix)
-        super(ViewPageTemplateFile, self).__init__(filename, _prefix)
+        super().__init__(filename, _prefix)
         if content_type is not None:
             self.content_type = content_type
 
@@ -69,7 +69,7 @@ class ViewPageTemplateFile(TrustedAppPT, PageTemplateFile):
         return getEngine()
 
     def pt_getContext(self, instance, request, **kw):
-        namespace = super(ViewPageTemplateFile, self).pt_getContext(**kw)
+        namespace = super().pt_getContext(**kw)
         namespace['request'] = request
         namespace['view'] = instance
         namespace['context'] = context = instance.context
@@ -97,7 +97,7 @@ class ViewPageTemplateFile(TrustedAppPT, PageTemplateFile):
         return BoundPageTemplate(self, instance)
 
 
-class ViewMapper(object):
+class ViewMapper:
     def __init__(self, ob, request):
         self.ob = ob
         self.request = request
@@ -109,7 +109,7 @@ class ViewMapper(object):
 # BoundPageTemplate object is returned.
 
 
-class BoundPageTemplate(object):
+class BoundPageTemplate:
     def __init__(self, pt, ob):
         object.__setattr__(self, '__func__', pt)
         object.__setattr__(self, '__self__', ob)
