@@ -14,7 +14,9 @@
 """Unit tests for the i18n framework
 """
 
-from zope.component.testing import setUp, tearDown
+from zope.component.testing import setUp
+from zope.component.testing import tearDown
+
 
 def test_directive():
     """
@@ -45,10 +47,10 @@ def test_directive():
     As you can see, both the default functionality and translation to
     German work:
 
-      >>> translate(msg)
-      u'This is an explicit message'
-      >>> translate(msg, target_language='de')
-      u'Dies ist eine explizite Nachricht'
+      >>> translate(msg) == u'This is an explicit message'
+      True
+      >>> translate(msg, target_language='de') == u'Dies ist eine explizite Nachricht'  # NOQA: E501
+      True
     """
 
 
