@@ -1,74 +1,87 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
-# FOR A PARTICULAR PURPOSE
+# FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
 
 import os
 from logging import getLogger
 
+from AccessControl.class_init import InitializeClass
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from AccessControl.SecurityManagement import getSecurityManager
-from App.class_init import InitializeClass
+from Acquisition import aq_get
+from Acquisition import aq_inner
+from Acquisition import aq_parent
 from App.Common import package_home
-from App.special_dtml import DTMLFile
 from App.config import getConfiguration
-from Acquisition import aq_parent, aq_inner, aq_get
 from ComputedAttribute import ComputedAttribute
 from OFS.SimpleItem import SimpleItem
 from OFS.Traversable import Traversable
-from Shared.DC.Scripts.Script import Script
-from Shared.DC.Scripts.Signature import FuncCode
 from Products.PageTemplates.Expressions import SecureModuleImporter
 from Products.PageTemplates.PageTemplate import PageTemplate
-
+from Products.PageTemplates.utils import encodingFromXMLPreamble
+from Shared.DC.Scripts.Script import Script
+from Shared.DC.Scripts.Signature import FuncCode
 from zope.contenttype import guess_content_type
+from zope.pagetemplate.pagetemplatefile import DEFAULT_ENCODING
+from zope.pagetemplate.pagetemplatefile import XML_PREFIX_MAX_LENGTH
+from zope.pagetemplate.pagetemplatefile import meta_pattern
 from zope.pagetemplate.pagetemplatefile import sniff_type
 
+
 LOG = getLogger('PageTemplateFile')
 
-def guess_type(filename, text):
 
+def guess_type(filename, body):
     # check for XML ourself since guess_content_type can't
     # detect text/xml  if 'filename' won't end with .xml
     # XXX: fix this in zope.contenttype
 
-    if text.startswith('<?xml'):
+    if body.startswith(b'<?xml') or filename.lower().endswith('.xml'):
         return 'text/xml'
 
-    content_type, dummy = guess_content_type(filename, text)
+    content_type, ignored_encoding = guess_content_type(filename, body)
     if content_type in ('text/html', 'text/xml'):
         return content_type
-    return sniff_type(text) or 'text/html'
+    return sniff_type(body) or 'text/html'
 
+
+# REFACT: Make this a subclass of
+# zope.pagetemplate.pagetemplatefile.PageTemplateFile
+# That class has been forked off of this code and now we have duplication.
+# They already share a common superclass
+# zope.pagetemplate.pagetemplate.PageTemplate
 class PageTemplateFile(SimpleItem, Script, PageTemplate, Traversable):
     """Zope 2 implementation of a PageTemplate loaded from a file."""
 
     meta_type = 'Page Template (File)'
 
-    func_defaults = None
-    func_code = FuncCode((), 0)
+    __code__ = FuncCode((), 0)
+    __defaults__ = None
     _v_last_read = 0
 
-    # needed by App.class_init.InitializeClass
+    # needed by AccessControl.class_init.InitializeClass
     _need__name__ = 1
 
     _default_bindings = {'name_subpath': 'traverse_subpath'}
 
     security = ClassSecurityInfo()
-    security.declareProtected('View management screens',
-      'read', 'document_src')
+    security.declareProtected(  # NOQA: D001
+        'View management screens', 'read', 'document_src')
 
-    def __init__(self, filename, _prefix=None, **kw):
+    def __init__(
+        self, filename, _prefix=None, encoding=DEFAULT_ENCODING, **kw
+    ):
         name = kw.pop('__name__', None)
-
+        self.encoding = encoding
         basepath, ext = os.path.splitext(filename)
 
         if name:
@@ -91,7 +104,7 @@ class PageTemplateFile(SimpleItem, Script, PageTemplate, Traversable):
     def pt_getContext(self):
         root = None
         meth = aq_get(self, 'getPhysicalRoot', None)
-        if meth is not None:
+        if callable(meth):
             root = meth()
         context = self._getContext()
         c = {'template': self,
@@ -109,14 +122,14 @@ class PageTemplateFile(SimpleItem, Script, PageTemplate, Traversable):
     def _exec(self, bound_names, args, kw):
         """Call a Page Template"""
         self._cook_check()
-        if not kw.has_key('args'):
+        if 'args' not in kw:
             kw['args'] = args
         bound_names['options'] = kw
 
         request = aq_get(self, 'REQUEST', None)
         if request is not None:
             response = request.response
-            if not response.headers.has_key('content-type'):
+            if 'content-type' not in response.headers:
                 response.setHeader('content-type', self.content_type)
 
         # Execute the template in a new security context.
@@ -140,8 +153,7 @@ class PageTemplateFile(SimpleItem, Script, PageTemplate, Traversable):
         return self.__name__  # Don't reveal filesystem paths
 
     def _cook_check(self):
-        import Globals  # for data
-        if self._v_last_read and not Globals.DevelopmentMode:
+        if self._v_last_read and not getConfiguration().debug_mode:
             return
         __traceback_info__ = self.filename
         try:
@@ -150,27 +162,46 @@ class PageTemplateFile(SimpleItem, Script, PageTemplate, Traversable):
             mtime = 0
         if self._v_program is not None and mtime == self._v_last_read:
             return
-        f = open(self.filename, "rb")
-        try:
-            text = f.read(XML_PREFIX_MAX_LENGTH)
-        except:
-            f.close()
-            raise
-        t = sniff_type(text)
-        if t != "text/xml":
-            # For HTML, we really want the file read in text mode:
-            f.close()
-            f = open(self.filename, 'U')
-            text = ''
-        text += f.read()
-        f.close()
-        self.pt_edit(text, t)
+        text, type_ = self._read_file()
+        self.pt_edit(text, type_)
         self._cook()
         if self._v_errors:
             LOG.error('Error in template %s' % '\n'.join(self._v_errors))
             return
         self._v_last_read = mtime
 
+    def _prepare_html(self, text):
+        match = meta_pattern.search(text)
+        if match is not None:
+            type_, encoding = (x.decode(self.encoding) for x in match.groups())
+            # TODO: Shouldn't <meta>/<?xml?> stripping
+            # be in PageTemplate.__call__()?
+            text = meta_pattern.sub(b"", text)
+        else:
+            type_ = None
+            encoding = self.encoding
+        text = text.decode(encoding)
+        return text, type_
+
+    def _prepare_xml(self, text):
+        if not isinstance(text, str):
+            encoding = encodingFromXMLPreamble(text, default=self.encoding)
+            text = text.decode(encoding)
+        return text, 'text/xml'
+
+    def _read_file(self):
+        __traceback_info__ = self.filename
+        with open(self.filename, "rb") as f:
+            text = f.read(XML_PREFIX_MAX_LENGTH)
+            type_ = sniff_type(text)
+            text += f.read()
+        if type_ != "text/xml":
+            text, type_ = self._prepare_html(text)
+        else:
+            text, type_ = self._prepare_xml(text)
+        f.close()
+        return text, type_
+
     def document_src(self, REQUEST=None, RESPONSE=None):
         """Return expanded document source."""
 
@@ -202,24 +233,8 @@ class PageTemplateFile(SimpleItem, Script, PageTemplate, Traversable):
 
     def __getstate__(self):
         from ZODB.POSException import StorageError
-        raise StorageError, ("Instance of AntiPersistent class %s "
-                             "cannot be stored." % self.__class__.__name__)
+        raise StorageError("Instance of AntiPersistent class %s "
+                           "cannot be stored." % self.__class__.__name__)
+
 
 InitializeClass(PageTemplateFile)
-
-XML_PREFIXES = [
-    "<?xml",                      # ascii, utf-8
-    "\xef\xbb\xbf<?xml",          # utf-8 w/ byte order mark
-    "\0<\0?\0x\0m\0l",            # utf-16 big endian
-    "<\0?\0x\0m\0l\0",            # utf-16 little endian
-    "\xfe\xff\0<\0?\0x\0m\0l",    # utf-16 big endian w/ byte order mark
-    "\xff\xfe<\0?\0x\0m\0l\0",    # utf-16 little endian w/ byte order mark
-    ]
-
-XML_PREFIX_MAX_LENGTH = max(map(len, XML_PREFIXES))
-
-def sniff_type(text):
-    for prefix in XML_PREFIXES:
-        if text.startswith(prefix):
-            return "text/xml"
-    return None
