@@ -18,8 +18,6 @@ import sys
 import types
 from time import asctime
 
-import six
-
 import AccessControl.users
 import App.ZApplication
 import OFS.Application
@@ -28,26 +26,11 @@ import Zope2
 from AccessControl.SecurityManagement import newSecurityManager
 from AccessControl.SecurityManagement import noSecurityManager
 from App.config import getConfiguration
-from zope.deferredimport import deprecated
 from zope.event import notify
 from zope.processlifetime import DatabaseOpened
 from zope.processlifetime import DatabaseOpenedWithRoot
 
 
-# BBB Zope 5.0
-deprecated(
-    'Please import from ZServer.ZPublisher.exceptionhook.',
-    RequestContainer='ZServer.ZPublisher.exceptionhook:RequestContainer',
-    zpublisher_exception_hook=(
-        'ZServer.ZPublisher.exceptionhook:EXCEPTION_HOOK'),
-    ZPublisherExceptionHook='ZServer.ZPublisher.exceptionhook:ExceptionHook',
-)
-
-deprecated(
-    'Please import from ZPublisher.WSGIPublisher.',
-    validated_hook='ZPublisher.WSGIPublisher:validate_user',
-)
-
 app = None
 startup_time = asctime()
 
@@ -72,7 +55,7 @@ def _load_custom_zodb(location):
             except SyntaxError:
                 return None
         module = types.ModuleType('Zope2.custom_zodb', 'Custom database')
-        six.exec_(code_obj, module.__dict__)
+        exec(code_obj, module.__dict__)
         sys.modules['Zope2.custom_zodb'] = module
         return module
 
