@@ -4,15 +4,6 @@ from Testing.ZopeTestCase import FunctionalTestCase
 from zExceptions import Unauthorized
 
 
-try:
-    from html import escape
-    import functools
-    # We do not want escaped " and ', as PageTemplate neither does it:
-    escape = functools.partial(escape, quote=False)
-except ImportError:  # PY2
-    from cgi import escape
-
-
 BAD_ATTR_STR = """
 <p tal:content="python:'class of {0} is {0.__class__}'.format(context)" />
 """
@@ -135,6 +126,7 @@ class FormatterFunctionalTest(FunctionalTestCase):
 
     def test_access_to_private_content_not_allowed_via_any_attribute(self):
         from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
+
         # If access to _delObject would be allowed, it would still only say
         # something like 'bound method _delObject', without actually deleting
         # anything, because methods are not executed in str.format, but there
@@ -150,10 +142,10 @@ class FormatterFunctionalTest(FunctionalTestCase):
             str(err.exception))
 
     def assert_is_checked_via_security_manager(self, pt_content):
-        from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
-        from AccessControl.SecurityManager import setSecurityPolicy
-        from AccessControl.SecurityManagement import noSecurityManager
         from AccessControl.SecurityManagement import getSecurityManager
+        from AccessControl.SecurityManagement import noSecurityManager
+        from AccessControl.SecurityManager import setSecurityPolicy
+        from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
 
         pt = ZopePageTemplate('mytemplate', pt_content)
         noSecurityManager()
@@ -187,8 +179,8 @@ class FormatterFunctionalTest(FunctionalTestCase):
         namespace = {'context': self.app}
         self.assertEqual(
             pt.pt_render(namespace).strip().replace('\r\n', '\n'),
-            u'<p>&lt;application at &gt;</p>\n'
-            u'<p>&lt;APPLICATION AT &gt;</p>')
+            '<p>&lt;application at &gt;</p>\n'
+            '<p>&lt;APPLICATION AT &gt;</p>')
 
     def test_cook_zope3_page_templates_using_format(self):
         from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
@@ -202,18 +194,18 @@ class FormatterFunctionalTest(FunctionalTestCase):
         self.app.test_folder_1_.__roles__ = ['Manager']
         self.assertEqual(
             pt.pt_render(namespace).strip().replace('\r\n', '\n'),
-            u"<p>class of &lt;application at &gt; is "
-            u"&lt;class 'ofs.application.application'&gt;</p>\n"
-            u"<p>CLASS OF &lt;APPLICATION AT &gt; IS "
-            u"&lt;CLASS 'OFS.APPLICATION.APPLICATION'&gt;</p>\n"
-            u"<p>{'foo': &lt;Folder at /test_folder_1_&gt;} has "
-            u"foo=&lt;Folder at test_folder_1_&gt;</p>\n"
-            u"<p>{'foo': &lt;Folder at /test_folder_1_&gt;} has "
-            u"foo=&lt;Folder at test_folder_1_&gt;</p>\n"
-            u"<p>[&lt;Folder at /test_folder_1_&gt;] has "
-            u"first item &lt;Folder at test_folder_1_&gt;</p>\n"
-            u"<p>[&lt;Folder at /test_folder_1_&gt;] has "
-            u"first item &lt;Folder at test_folder_1_&gt;</p>"
+            "<p>class of &lt;application at &gt; is "
+            "&lt;class 'ofs.application.application'&gt;</p>\n"
+            "<p>CLASS OF &lt;APPLICATION AT &gt; IS "
+            "&lt;CLASS 'OFS.APPLICATION.APPLICATION'&gt;</p>\n"
+            "<p>{'foo': &lt;Folder at /test_folder_1_&gt;} has "
+            "foo=&lt;Folder at test_folder_1_&gt;</p>\n"
+            "<p>{'foo': &lt;Folder at /test_folder_1_&gt;} has "
+            "foo=&lt;Folder at test_folder_1_&gt;</p>\n"
+            "<p>[&lt;Folder at /test_folder_1_&gt;] has "
+            "first item &lt;Folder at test_folder_1_&gt;</p>\n"
+            "<p>[&lt;Folder at /test_folder_1_&gt;] has "
+            "first item &lt;Folder at test_folder_1_&gt;</p>"
         )
 
     def test_cook_zope2_page_templates_bad_key_str(self):
