@@ -17,29 +17,6 @@ from socket import gethostbyaddr
 
 import ipaddress
 
-from zope.deferredimport import deprecated
-
-
-# BBB Zope 5.0
-_prefix = 'ZServer.Zope2.Startup.handlers:'
-deprecated(
-    'Please import from ZServer.Zope2.Startup.handlers.',
-    handleConfig=_prefix + 'handleConfig',
-    root_handler=_prefix + 'root_handler',
-    maximum_number_of_session_objects=(
-        _prefix + 'maximum_number_of_session_objects'),
-    session_add_notify_script_path=(
-        _prefix + 'session_add_notify_script_path'),
-    session_delete_notify_script_path=(
-        _prefix + 'session_delete_notify_script_path'),
-    session_timeout_minutes=_prefix + 'session_timeout_minutes',
-    large_file_threshold=_prefix + 'large_file_threshold',
-    max_listen_sockets=_prefix + 'max_listen_sockets',
-    cgi_maxlen=_prefix + 'cgi_maxlen',
-    http_header_max_length=_prefix + 'http_header_max_length',
-    enable_ms_public_header=_prefix + 'enable_ms_public_header',
-)
-
 
 def _setenv(name, value):
     if isinstance(value, str):
